
#include <gdk-pixbuf/gdk-pixbuf.h>

struct prefs;

extern const char *download_cardart_key;
extern const char *cache_directory_key;

void cardart_initialize (struct prefs *prefs);
struct cardart *cardart_load_cardart (char *cardname, char *expansions);
struct cardart *cardart_load_cardart3 (char *cardname, char *expansions, int);
void cardart_destroy (struct cardart *);

GdkPixbuf *cardart_get_card_image (struct cardinfo *);
GdkPixbuf *cardart_get_unscaled_art (struct cardinfo *);
GdkPixbuf *cardart_get_small_art (struct cardinfo *, int width, int height);
struct cardart *cardart_get_null_art (void);
